@@ -80,7 +80,7 @@ library(dplyr)
 m4 <- ordinal::clm(factor(gear) ~ wt + cyl + disp, data = mtcars)
 m4_df <- coef(summary(m4)) %>% 
   data.frame() %>% 
-  add_rownames("term") %>%
+  tibble::rownames_to_column("term") %>%
   rename(estimate = Estimate, std.error = Std..Error)
 m4_df
 dwplot(m4_df)
@@ -98,7 +98,7 @@ dwplot(m1_df_mod)
 # Create a data.frame of marginal effects
 m5 <- mfx::logitmfx(formula = am ~ wt + cyl + disp, data = mtcars) 
 m5_margin <- data.frame(m5$mfxest) %>% 
-  add_rownames("term") %>% 
+  tibble::rownames_to_column("term") %>% 
   rename(estimate = dF.dx, std.error = Std..Err.)
 m5_margin
 dwplot(m5_margin)
@@ -198,16 +198,19 @@ ordered_vars <- c("wt", "cyl", "disp", "hp", "gear")
 mod <- "mpg ~ wt"
 
 by_trans <- mtcars %>% group_by(am) %>%  # group data by transmission
-  do(tidy(lm(mod, data = .))) %>%        # run model on each group
-  rename(submodel = am) %>%              # make submodel variable
-  mutate(model = "Model 1")              # make model variable
+    do(tidy(lm(mod, data = .))) %>%        # run model on each group
+    rename(submodel = am) %>%              # make submodel variable
+    mutate(model = "Model 1") %>%          # make model variable
+    ungroup()
+
 
 for (i in 2:5) {
   mod <- paste(mod, "+", ordered_vars[i])
   by_trans <- rbind(by_trans, mtcars %>% group_by(am) %>%
                    do(tidy(lm(mod, data = .))) %>%
                    rename(submodel = am) %>%
-                   mutate(model = paste("Model", i)))
+                   mutate(model = paste("Model", i)) %>% 
+                       ungroup())
 }
 
 # Relabel predictors (they will appear as facet labels)
